#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-compat
version:              0.95.2.2
visibility:           public
id:                   regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
key:                  regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           Andreas Abel
author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Replaces/enhances "Text.Regex"
description:
    One module compat layer over <//hackage.haskell.org/package/regex-posix regex-posix> to replace "Text.Regex".

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  002c3bd8d942ec8b23b1b6f893a824c3
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.6.6/site-local/regex-compat-0.95.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/regex-compat-0.95.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/regex-compat-0.95.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat
hs-libraries:         HSregex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
depends:
    array-0.5.6.0 base-4.18.2.1
    regex-base-0.94.0.3-6fVrfocUW2t4u08iX8Rj6b
    regex-posix-0.96.0.2-LsCmj8tXKerCmkZ6TKO5qF

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

